autowisp.database.initialize_light_curve_structure module — AutoWISP documentation

# autowisp.database.initialize_light_curve_structure module

## Class Inheritance Diagram

Define function to add defaults to all light curve structure tables.

autowisp.database.initialize_light_curve_structure._get_attributes(db_session)

  Return a list of all attributes of light cuves.

autowisp.database.initialize_light_curve_structure._get_catalogue_attributes()

  Create the attributes for catalogue information for this source.

autowisp.database.initialize_light_curve_structure._get_configuration_index_datasets(db_session)

  Return a list of datasets of indicies within configuration datasets.

autowisp.database.initialize_light_curve_structure._get_data_reduction_attribute_datasets(db_session)

  Return all datasets from attributes in data reduction files.

autowisp.database.initialize_light_curve_structure._get_data_reduction_dataset_datasets(db_session)

  Return datasets built from entries for the source in DR datasets.

autowisp.database.initialize_light_curve_structure._get_datasets(db_session)

  Return a list of all datasets in light curves.

autowisp.database.initialize_light_curve_structure._get_detrended_datasets(magfit_datasets, mode='epd')

  Create the default datasets for storing detrending results.

  Parameters:

    magfit_datasets (dict) – The light curve datasets containing the magnitude fitted magnitudes indexed by the photometry method.

autowisp.database.initialize_light_curve_structure._get_frame_datasets()

  Return all datasets containing FITS header keywords.

autowisp.database.initialize_light_curve_structure._get_sky_position_datasets()

  Return datasets describing when and where on the sky the source is.

autowisp.database.initialize_light_curve_structure._get_source_extraction_datasets()

  Create the default datasets for source extraction data.

autowisp.database.initialize_light_curve_structure.get_default_light_curve_structure(db_session)

  Create default configuration for the layout of light curve files.

autowisp.database.initialize_light_curve_structure.transform_dr_to_lc_path(pipeline_key, dr_path)

  Return the path in a light curve file corresponding to a DR file path.